@@ -5,19 +5,23 @@ use warnings;
 
 use base 'Devel::hdb::App::Base';
 
-our $VERSION = '0.23_15';
+use Devel::hdb::Response;
 
-__PACKAGE__->add_route('post', '/exit', \&do_terminate);
+__PACKAGE__->add_route('get', '/exit', \&do_terminate);
 
-# Exit the running program and then exit()
+# Exit the running program
+# Sets up as a long_call so we can send the 'hangup' response
+# and then exit()
 sub do_terminate {
     my($class, $app, $env) = @_;
     my $json = $app->{json};
-    $app->user_requested_exit();
+    DB->user_requested_exit();
     return sub {
         my $responder = shift;
-        my $writer = $responder->([ 204, [ 'Content-Type' => 'application/json' ]]);
+        my $writer = $responder->([ 200, [ 'Content-Type' => 'application/json' ]]);
 
+        my $resp = Devel::hdb::Response->new('hangup');
+        $writer->write($resp->encode);
         $writer->close();
         exit();
     };
@@ -33,12 +37,12 @@ Devel::hdb::App::Terminate - Terminate the debugged process
 
 =head1 DESCRIPTION
 
-Registers a route for POST /exit that terminates the debugged process, as
+Registers a route for GET /exit that terminates the debugged process, as
 well as the HTTP listener.
 
 =head1 SEE ALSO
 
-L<Devel::hdb>
+Devel::hdb
 
 =head1 AUTHOR
 
@@ -46,5 +50,5 @@ Anthony Brummett <brummett@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2014, Anthony Brummett.  This module is free software. It may
+Copyright 2013, Anthony Brummett.  This module is free software. It may
 be used, redistributed and/or modified under the same terms as Perl itself.
