@@ -559,11 +559,18 @@ function Debugger(sel) {
             filename = $elt.closest('[data-filename]').attr('data-filename'),
             lineno = $elt.closest('[data-lineno]').attr('data-lineno'),
             type = $elt.hasClass('breakpoint-condition') ? 'condition' : 'action',
+            bp_data = this.breakpointManager.get(filename, lineno),
+            bp_condition = bp_data[type],
             dbg = this;
 
+        var form_html = '<form><input class="span2" type="text" name="input" '
+                        + ( bp_condition ? ( 'value="' + bp_condition + '"' )
+                                         : '' )
+                        + 'placeholder="'+type+'" autofocus="true"></form>';
+
         e.stopPropagation();  // Keep the popover from disappearing from the click watcher
         $elt.empty()
-            .append('<form><input class="span2" type="text" name="input" placeholder="'+type+'" autofocus="true"></form>')
+            .append(form_html)
             .submit(function(e) {
                 var form = e.target,
                     value = form.elements['input'].value;
@@ -579,7 +586,8 @@ function Debugger(sel) {
                     // It was part of the right-click breakpoint menu
                     dbg._drawBreakpointRightClickMenu(dbg.breakpointPopover);
                 }
-            });
+            })
+            .find('input').focus();
     };
 
     this.getStack = function() {
@@ -725,7 +733,28 @@ function Debugger(sel) {
         codeTable.find('.active').removeClass('active');
         var activeLine = codeTable.find('.code-line:nth-child('+line+')').addClass('active');
 
-        this._scrollCodeTableLineIntoView(codeTable, line);
+        var scrollCodeTable = function() {
+            dbg._scrollCodeTableLineIntoView(codeTable, line);
+        };
+
+        var codeTableTabPane = codeTable.closest('.tab-pane');
+        if (codeTableTabPane.hasClass('active')) {
+            // this is the currently active tab, scroll it now
+            scrollCodeTable();
+        } else {
+            // Not the active tab - arrange for it to scroll the first time it becomes active
+            var stackId = codeTableTabPane.attr('id'),
+                relatedTab = $('#stack-tabs a[href="#'+stackId+'"]'),
+                autoScrollOnce = true;
+            relatedTab.on('shown', function(e) {
+                // relatedTarget is true when the anchor was actually clicked?
+                // seems to be undefined during mouseover of the anchor
+                if (autoScrollOnce && e.relatedTarget) {
+                    scrollCodeTable();
+                    autoScrollOnce = false;
+                }
+            });
+        }
     };
 
     // Ensure the given line number of the codeTable is visible
@@ -784,7 +813,15 @@ function Debugger(sel) {
             tab = $( this.templates.navTab({active: i === 0}) );
             tab.appendTo(tabs);
         }
+
+        var wantarray_sigil = '';
+        if (frame.wantarray == 0) {
+            wantarray_sigil = '$';
+        } else if (frame.wantarray) {
+            wantarray_sigil = '@';
+        }
         html = this.templates.navTabContent({ label: frame.subname,
+                                            wantarray: wantarray_sigil,
                                             longlabel: frame.subroutine,
                                             tabId: tabId,
                                             filename: filename,
@@ -893,10 +930,17 @@ function Debugger(sel) {
     };
     this.toggleCollapseWatchExpression = function(e) {
         var collapsable = $(e.target),
-            toCollapse = collapsable.siblings('dl,ul')
+            toCollapse = collapsable.siblings('dl,ul'),
+            isCollapsed = collapsable.hasClass('collapsed');
 
         e.preventDefault();
-        toCollapse.toggle(100);
+        toCollapse.toggle(100, function() {
+            if (isCollapsed) {
+                collapsable.removeClass('collapsed');
+            } else {
+                collapsable.addClass('collapsed');
+            }
+        });
     };
     this.addEditWatchExpression = function(e) {
         var newExprInput = $('<input type="text" name="expr">'),
